@@ -11,18 +11,18 @@ sub dump {
     #                                   missing
     my $class = shift;
     my $argvs = shift // return undef;
-
     return undef unless ref $argvs eq 'Sisimai::Data';
+
     my $damneddata = undef;
     my $jsonstring = '';
-    my $jsonobject = JSON->new;
+    my $jsonparser = JSON->new;
 
     eval {
         $damneddata = $argvs->damn;
-        $jsonobject->space_after(1);
-        $jsonstring = $jsonobject->encode($damneddata);
+        $jsonparser->space_after(1);
+        $jsonstring = $jsonparser->encode($damneddata);
     };
-
+    warn sprintf(" ***warning: Something is wrong in JSON encoding: %s", $@) if $@;
     return $jsonstring;
 }
 
@@ -69,7 +69,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
