@@ -84,9 +84,12 @@ sub to_plain {
 
     if( $loose || $plain =~ $match->{'html'} || $plain =~ $match->{'body'} ) {
         # <html> ... </html>
-        # Rewrite <a> elements
-        # 1. <a href = 'http://...'>...</a> to " http://... "
-        # 2. <a href = 'mailto:...'>...</a> to " Value <mailto:...> "
+        # 1. Remove <head>...</head>
+        # 2. Remove <style>...</style>
+        # 3. <a href = 'http://...'>...</a> to " http://... "
+        # 4. <a href = 'mailto:...'>...</a> to " Value <mailto:...> "
+        $plain =~ s|<head>.+</head>||gsim;
+        $plain =~ s|<style.+?>.+</style>||gsim;
         $plain =~ s|<a\s+href\s*=\s*['"](https?://.+?)['"].*?>(.*?)</a>| [$2]($1) |gsim;
         $plain =~ s|<a\s+href\s*=\s*["']mailto:([^\s]+?)["']>(.*?)</a>| [$2](mailto:$1) |gsim;
 
